pub(crate) fn search_upward(
start: impl AsRef<Path>,
end: impl AsRef<Path>,
item: impl AsRef<Path>,
) -> Vec<PathBuf>Expand description
This function searches upward from start for directories or files matching item.
It returns a Vec<PathBuf> to all found instances in order of closest to furthest away.
The function only searches up within subdirectories of end.