pub(crate) fn uint_idx_to_alpha_idx(
idx: VisibleItemIndex,
nvariables: usize,
) -> StringExpand description
This function takes a number and converts it’s digits into the range a-p. This is nice because it makes for some easily typed ids. The function first formats the number as a hex digit and then performs the mapping.